hvl\_ccb.new\_path.class\_file
==============================



.. inheritance-diagram:: hvl_ccb.new_path.class_file
   :parts: 1


.. automodule:: hvl_ccb.new_path.class_file
   :members:
   :undoc-members:
   :show-inheritance:
